Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(449)

Unified Diff: net/quic/quic_protocol.h

Issue 11820005: Largest received -> largest observed. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: rebase Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/quic/quic_framer_test.cc ('k') | net/quic/quic_protocol.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/quic/quic_protocol.h
diff --git a/net/quic/quic_protocol.h b/net/quic/quic_protocol.h
index 04fbd9142191989f7588d6b1604ccbedf2a8a6d9..45d63a2bedac26dc811122aa710c855c85538342 100644
--- a/net/quic/quic_protocol.h
+++ b/net/quic/quic_protocol.h
@@ -198,7 +198,7 @@ struct NET_EXPORT_PRIVATE ReceivedPacketInfo {
// Records a packet receipt.
void RecordReceived(QuicPacketSequenceNumber sequence_number);
// True if the sequence number is greater than largest_received or is listed
// as missing.
// Always returns false for sequence numbers less than least_unacked.
bool IsAwaitingPacket(QuicPacketSequenceNumber sequence_number) const;
@@ -206,8 +206,15 @@ struct NET_EXPORT_PRIVATE ReceivedPacketInfo {
// Clears all missing packets less than |least_unacked|.
void ClearMissingBefore(QuicPacketSequenceNumber least_unacked);
- // The highest packet sequence number we've received from the peer.
- QuicPacketSequenceNumber largest_received;
+ // The highest packet sequence number we've observed from the peer.
+ //
+ // In general, this should be the largest packet number we've received. In
+ // the case of truncated acks, we may have to advertise a lower "upper bound"
+ // than largest received, to avoid implicitly acking missing packets that
+ // don't fit in the missing packet list due to size limitations. In this
+ // case, largest_observed may be a packet which is also in the missing packets
+ // list.
+ QuicPacketSequenceNumber largest_observed;
// The set of packets which we're expecting and have not received.
SequenceSet missing_packets;
@@ -226,8 +233,8 @@ struct NET_EXPORT_PRIVATE SentPacketInfo {
struct NET_EXPORT_PRIVATE QuicAckFrame {
QuicAckFrame() {}
// Testing convenience method to construct a QuicAckFrame with all packets
- // from least_unacked to largest_received acked.
- QuicAckFrame(QuicPacketSequenceNumber largest_received,
+ // from least_unacked to largest_observed acked.
+ QuicAckFrame(QuicPacketSequenceNumber largest_observed,
QuicPacketSequenceNumber least_unacked);
NET_EXPORT_PRIVATE friend std::ostream& operator<<(
« no previous file with comments | « net/quic/quic_framer_test.cc ('k') | net/quic/quic_protocol.cc » ('j') | no next file with comments »
@@ -198,7 +198,7 @@ struct NET_EXPORT_PRIVATE ReceivedPacketInfo {
// Records a packet receipt.
void RecordReceived(QuicPacketSequenceNumber sequence_number);
- // True if the sequence number is greater than largest_received or is listed
+ // True if the sequence number is greater than largest_observed or is listed
// as missing.
// Always returns false for sequence numbers less than least_unacked.

Powered by Google App Engine
This is Rietveld 408576698